"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from lambdadb.types import BaseModel
from lambdadb.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class UpdateDocsDocTypedDict(TypedDict):
    pass


class UpdateDocsDoc(BaseModel):
    pass


class UpdateDocsRequestBodyTypedDict(TypedDict):
    docs: List[UpdateDocsDocTypedDict]
    r"""A list of documents to update. Each document must contain 'id' field to be updated."""


class UpdateDocsRequestBody(BaseModel):
    docs: List[UpdateDocsDoc]
    r"""A list of documents to update. Each document must contain 'id' field to be updated."""


class UpdateDocsRequestTypedDict(TypedDict):
    project_name: str
    r"""Project name."""
    collection_name: str
    r"""Collection name."""
    request_body: UpdateDocsRequestBodyTypedDict


class UpdateDocsRequest(BaseModel):
    project_name: Annotated[
        str,
        pydantic.Field(alias="projectName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Project name."""

    collection_name: Annotated[
        str,
        pydantic.Field(alias="collectionName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Collection name."""

    request_body: Annotated[
        UpdateDocsRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class UpdateDocsResponseTypedDict(TypedDict):
    r"""Update request accepted."""

    message: NotRequired[str]


class UpdateDocsResponse(BaseModel):
    r"""Update request accepted."""

    message: Optional[str] = None
